==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_bez.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_bez extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "TZS", "TSh" },
            { "aed", "Lupila lwa Hufalme dza Huhihalabu" },
            { "aoa", "Lupila lwa Huangola" },
            { "aud", "Lupila lwa Huaustlalia" },
            { "bhd", "Lupila lwa Hubahareni" },
            { "bif", "Lupila lwa Huburundi" },
            { "bwp", "Lupila lwa Hubotswana" },
            { "cad", "Lupila lwa Hukanada" },
            { "cdf", "Lupila lwa Hukongo" },
            { "chf", "Lupila lwa Huuswisi" },
            { "cny", "Lupila lwa Huchina" },
            { "cve", "Lupila lwa Hukepuvede" },
            { "djf", "Lupila lwa Hujibuti" },
            { "dzd", "Lupila lwa Hualjelia" },
            { "egp", "Lupila lwa Humisri" },
            { "ern", "Lupila lwa Hueritrea" },
            { "etb", "Lupila lwa Huuhabeshi" },
            { "eur", "Lupila lwa Yulo" },
            { "gbp", "Lupila lwa Huuingereza" },
            { "ghc", "Lupila lwa Hughana" },
            { "gmd", "Lupila lwa Hugambia" },
            { "gns", "Lupila lwa Hujine" },
            { "inr", "Lupila lwa Huindia" },
            { "jpy", "Lupila lwa Hijapani" },
            { "kes", "Shilingi ya Hukenya" },
            { "kmf", "Lupila lwa Hukomoro" },
            { "lrd", "Lupila lwa Hulibelia" },
            { "lsl", "Lupila lwa Hulesoto" },
            { "lyd", "Lupila lwa Hulibya" },
            { "mad", "Lupila lwa Humoloko" },
            { "mga", "Lupila lwa Hubukini" },
            { "mro", "Lupila lwa Humolitania (1973\u20132017)" },
            { "mru", "Lupila lwa Humolitania" },
            { "mur", "Lupila lwa Humolisi" },
            { "mwk", "Lupila lwa Humalawi" },
            { "mzm", "Lupila lwa Humsumbiji" },
            { "nad", "Lupila lwa Hunamibia" },
            { "ngn", "Lupila lwa Hunijelia" },
            { "rwf", "Lupila lwa Hurwanda" },
            { "sar", "Lupila lwa Husaudi" },
            { "scr", "Lupila lwa Hushelisheli" },
            { "sdg", "Lupila lwa Husudani" },
            { "shp", "Lupila lwa Husantahelena" },
            { "sll", "Lupila lwa Lioni" },
            { "sos", "Lupila lwa Husomalia" },
            { "std", "Lupila lwa Husaotome na Huprinisipe (1977\u20132017)" },
            { "stn", "Lupila lwa Husaotome na Huprinisipe" },
            { "szl", "Lupila lwa Lilangeni" },
            { "tnd", "Lupila lwa Hutunisia" },
            { "tzs", "Shilingi ya Hutanzania" },
            { "ugx", "Shilingi ya Huuganda" },
            { "usd", "Lupila lwa Humalekani" },
            { "xaf", "Lupila lwa CFA BEAC" },
            { "xof", "Lupila lwa CFA BCEAO" },
            { "zar", "Lupila lwa Huafriaka ya Hukusini" },
            { "zmk", "Lupila lwa Huzambia (1968\u20132012)" },
            { "zmw", "Lupila lwa Huzambia" },
            { "zwd", "Lupila lwa Huzimbabwe" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_bez.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_bez extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "TZS", "TSh" },
            { "aed", "Lupila lwa Hufalme dza Huhihalabu" },
            { "aoa", "Lupila lwa Huangola" },
            { "aud", "Lupila lwa Huaustlalia" },
            { "bhd", "Lupila lwa Hubahareni" },
            { "bif", "Lupila lwa Huburundi" },
            { "bwp", "Lupila lwa Hubotswana" },
            { "cad", "Lupila lwa Hukanada" },
            { "cdf", "Lupila lwa Hukongo" },
            { "chf", "Lupila lwa Huuswisi" },
            { "cny", "Lupila lwa Huchina" },
            { "cve", "Lupila lwa Hukepuvede" },
            { "djf", "Lupila lwa Hujibuti" },
            { "dzd", "Lupila lwa Hualjelia" },
            { "egp", "Lupila lwa Humisri" },
            { "ern", "Lupila lwa Hueritrea" },
            { "etb", "Lupila lwa Huuhabeshi" },
            { "eur", "Lupila lwa Yulo" },
            { "gbp", "Lupila lwa Huuingereza" },
            { "ghc", "Lupila lwa Hughana" },
            { "gmd", "Lupila lwa Hugambia" },
            { "gns", "Lupila lwa Hujine" },
            { "inr", "Lupila lwa Huindia" },
            { "jpy", "Lupila lwa Hijapani" },
            { "kes", "Shilingi ya Hukenya" },
            { "kmf", "Lupila lwa Hukomoro" },
            { "lrd", "Lupila lwa Hulibelia" },
            { "lsl", "Lupila lwa Hulesoto" },
            { "lyd", "Lupila lwa Hulibya" },
            { "mad", "Lupila lwa Humoloko" },
            { "mga", "Lupila lwa Hubukini" },
            { "mro", "Lupila lwa Humolitania (1973\u20132017)" },
            { "mru", "Lupila lwa Humolitania" },
            { "mur", "Lupila lwa Humolisi" },
            { "mwk", "Lupila lwa Humalawi" },
            { "mzm", "Lupila lwa Humsumbiji" },
            { "nad", "Lupila lwa Hunamibia" },
            { "ngn", "Lupila lwa Hunijelia" },
            { "rwf", "Lupila lwa Hurwanda" },
            { "sar", "Lupila lwa Husaudi" },
            { "scr", "Lupila lwa Hushelisheli" },
            { "sdg", "Lupila lwa Husudani" },
            { "shp", "Lupila lwa Husantahelena" },
            { "sle", "Lupila lwa Lioni" },
            { "sll", "Lupila lwa Lioni (1964\u20142022)" },
            { "sos", "Lupila lwa Husomalia" },
            { "std", "Lupila lwa Husaotome na Huprinisipe (1977\u20132017)" },
            { "stn", "Lupila lwa Husaotome na Huprinisipe" },
            { "szl", "Lupila lwa Lilangeni" },
            { "tnd", "Lupila lwa Hutunisia" },
            { "tzs", "Shilingi ya Hutanzania" },
            { "ugx", "Shilingi ya Huuganda" },
            { "usd", "Lupila lwa Humalekani" },
            { "xaf", "Lupila lwa CFA BEAC" },
            { "xof", "Lupila lwa CFA BCEAO" },
            { "zar", "Lupila lwa Huafriaka ya Hukusini" },
            { "zmk", "Lupila lwa Huzambia (1968\u20132012)" },
            { "zmw", "Lupila lwa Huzambia" },
            { "zwd", "Lupila lwa Huzimbabwe" },
        };
        return data;
    }
}
